Production platform
=====================

![alt text](images/technical_overview.png)

Above you can see the old production platform.

The current 'production platform' is aquasuite-ml, and it has grown far beyond the scope of this package.
